==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/LineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalAnchoredCategorySeriesDescriptionMetadata } from "./HorizontalAnchoredCategorySeriesDescriptionMetadata";
import { LineSeriesDescription } from "./LineSeriesDescription";
/**
 * @hidden
 */
var LineSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(LineSeriesDescriptionMetadata, _super);
    function LineSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    LineSeriesDescriptionMetadata.b = function (a) {
        if (LineSeriesDescriptionMetadata.a == null) {
            LineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            LineSeriesDescriptionMetadata.c(LineSeriesDescriptionMetadata.a);
        }
        if (a.g(LineSeriesDescriptionMetadata.a)) {
            return;
        }
        a.s(LineSeriesDescriptionMetadata.a);
    };
    LineSeriesDescriptionMetadata.c = function (a) {
        HorizontalAnchoredCategorySeriesDescriptionMetadata.c(a);
        a.item("UnknownValuePlotting", "ExportedType:string:UnknownValuePlotting");
        a.item("UnknownValuePlotting@names", "LinearInterpolate;DontPlot");
    };
    LineSeriesDescriptionMetadata.d = function (a) {
        LineSeriesDescriptionMetadata.b(a);
        a.u("LineSeries", function () { return new LineSeriesDescription(); });
        a.t("LineSeries", LineSeriesDescriptionMetadata.a);
    };
    LineSeriesDescriptionMetadata.$t = markType(LineSeriesDescriptionMetadata, 'LineSeriesDescriptionMetadata');
    LineSeriesDescriptionMetadata.a = null;
    return LineSeriesDescriptionMetadata;
}(Base));
export { LineSeriesDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/LineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalAnchoredCategorySeriesDescriptionMetadata } from "./HorizontalAnchoredCategorySeriesDescriptionMetadata";
import { LineSeriesDescription } from "./LineSeriesDescription";
/**
 * @hidden
 */
var LineSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(LineSeriesDescriptionMetadata, _super);
    function LineSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    LineSeriesDescriptionMetadata.b = function (a) {
        if (LineSeriesDescriptionMetadata.a == null) {
            LineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            LineSeriesDescriptionMetadata.c(LineSeriesDescriptionMetadata.a);
        }
        if (a.j(LineSeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(LineSeriesDescriptionMetadata.a);
    };
    LineSeriesDescriptionMetadata.c = function (a) {
        HorizontalAnchoredCategorySeriesDescriptionMetadata.c(a);
        a.item("UnknownValuePlotting", "ExportedType:string:UnknownValuePlotting");
        a.item("UnknownValuePlotting@names", "LinearInterpolate;DontPlot");
    };
    LineSeriesDescriptionMetadata.d = function (a) {
        LineSeriesDescriptionMetadata.b(a);
        a.aa("LineSeries", function () { return new LineSeriesDescription(); });
        a.z("LineSeries", LineSeriesDescriptionMetadata.a);
    };
    LineSeriesDescriptionMetadata.$t = markType(LineSeriesDescriptionMetadata, 'LineSeriesDescriptionMetadata');
    LineSeriesDescriptionMetadata.a = null;
    return LineSeriesDescriptionMetadata;
}(Base));
export { LineSeriesDescriptionMetadata };
